@@ -30,7 +30,7 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
 
-#ifdef HAVE_EXIF
+#ifdef HAVE_LIBEXIF_GTK
 #  include <libexif-gtk/gtk-exif-browser.h>
 #endif
 
@@ -117,7 +117,7 @@ gtkam_exif_new (GtkamCamera *camera, const gchar *folder, const gchar *file)
 {
 	GtkamExif *exif;
 	GtkWidget *button;
-#ifdef HAVE_EXIF
+#ifdef HAVE_LIBEXIF
 	GtkWidget *dialog, *browser, *c;
 	CameraFile *cfile;
 	int result;
@@ -130,7 +130,7 @@ gtkam_exif_new (GtkamCamera *camera, const gchar *folder, const gchar *file)
 
 	g_return_val_if_fail (GTKAM_IS_CAMERA (camera), NULL);
 
-#ifdef HAVE_EXIF
+#ifdef HAVE_LIBEXIF
 	/* Get exif data */
 	gp_file_new (&cfile);
 	c = gtkam_cancel_new (
@@ -150,8 +150,8 @@ gtkam_exif_new (GtkamCamera *camera, const gchar *folder, const gchar *file)
 	default:
 		gp_file_unref (cfile);
 		dialog = gtkam_error_new (result, GTKAM_CANCEL (c)->context,
-			NULL, _("Could not get exif information for "
-			"'%s' in folder '%s'"), file, folder);
+			NULL, _("Could not get EXIF information for "
+			"'%s' in folder '%s'."), file, folder);
 		gtk_widget_show (dialog);
 		gtk_object_destroy (GTK_OBJECT (c));
 		return (NULL);
@@ -167,7 +167,7 @@ gtkam_exif_new (GtkamCamera *camera, const gchar *folder, const gchar *file)
 		gtk_widget_show (dialog);
 		return (NULL);
 	}
-printf("data is %s\n", data);	
+/*printf("data is %s\n", data);	*/
 	/* FIXME Hack, since library fails to return error code, instead
 	   populating edata with 'Exif' */
 	if (g_ascii_strcasecmp (data, "Exif") == 0) {
@@ -180,7 +180,7 @@ printf("data is %s\n", data);
 
 	exif = g_object_new (GTKAM_TYPE_EXIF, NULL);
 
-#ifdef HAVE_EXIF
+#ifdef HAVE_LIBEXIF_GTK
 	browser = gtk_exif_browser_new ();
 	gtk_exif_browser_set_data (GTK_EXIF_BROWSER (browser), edata);
 	exif_data_unref (edata);
@@ -189,7 +189,7 @@ printf("data is %s\n", data);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (exif)->vbox), browser,
 			    TRUE, TRUE, 0);
 #else
-	label = gtk_label_new (_("Gtkam has been compiled without exif "
+	label = gtk_label_new (_("Gtkam has been compiled without EXIF "
 		"support."));
 	gtk_widget_show (label);
 	gtk_container_set_border_width (GTK_CONTAINER (label), 5);
